@@ -11,7 +11,7 @@ import os.path
 from os import path
 import numpy as np
 import pandas as pd
-# from snowflake.connector.pandas_tools import pd_writer
+from snowflake.connector.pandas_tools import pd_writer
 import pytz
 import hashlib
 import getpass
@@ -179,10 +179,9 @@ def load_via_sql_snowflake(load_df, tbl_name, secret_name = 'fbi_snowflake_creds
 
     print('loading...')
     # load_df.to_sql(tbl_name, con=conn, index=False, if_exists='append', method=pd_writer)
-    load_df.to_sql(tbl_name, con=engine.connect(), if_exists='append', index=False)
+    load_df.to_sql(tbl_name, con=engine.connect(), if_exists='append', index=False, method=pd_writer)
     print('all done!')
 
-    engine.dispose()
     conn.close()
 
 def get_logger(filename):
